all
rule 'MD013', :ignore_code_blocks => true

rule 'MD026', :punctuation => '.,:;'

exclude_rule 'MD041'
